summaryrefslogtreecommitdiffstats
path: root/webkit/api/public
diff options
context:
space:
mode:
Diffstat (limited to 'webkit/api/public')
-rw-r--r--webkit/api/public/WebURLRequest.h6
-rw-r--r--webkit/api/public/WebURLResponse.h3
2 files changed, 6 insertions, 3 deletions
diff --git a/webkit/api/public/WebURLResponse.h b/webkit/api/public/WebURLResponse.h
index cb17d65..1674f21 100644
--- a/webkit/api/public/WebURLResponse.h
+++ b/webkit/api/public/WebURLResponse.h
@@ -100,6 +100,9 @@ namespace WebKit {
WEBKIT_API long long appCacheID() const;
WEBKIT_API void setAppCacheID(long long);
+ WEBKIT_API WebURL appCacheManifestURL() const;
+ WEBKIT_API void setAppCacheManifestURL(const WebURL&);
+
// A consumer controlled value intended to be used to record opaque
// security info related to this request.
WEBKIT_API WebCString securityInfo() const;
diff --git a/webkit/api/public/WebURLRequest.h b/webkit/api/public/WebURLRequest.h
index 0cdd71b..5e312d1 100644
--- a/webkit/api/public/WebURLRequest.h
+++ b/webkit/api/public/WebURLRequest.h
@@ -129,9 +129,9 @@ namespace WebKit {
WEBKIT_API int requestorProcessID() const;
WEBKIT_API void setRequestorProcessID(int);
- // Allows the request to be matched up with its app cache context.
- WEBKIT_API int appCacheContextID() const;
- WEBKIT_API void setAppCacheContextID(int id);
+ // Allows the request to be matched up with its app cache host.
+ WEBKIT_API int appCacheHostID() const;
+ WEBKIT_API void setAppCacheHostID(int id);
#if defined(WEBKIT_IMPLEMENTATION)
WebCore::ResourceRequest& toMutableResourceRequest();